@@ -21,13 +21,14 @@ except ImportError:
 import logging
 import os
 
-from keystoneclient import access
-from keystoneclient import adapter
+import debtcollector.renames
+from keystoneauth1 import access
+from keystoneauth1 import adapter
 import requests
 
+from neutronclient._i18n import _
 from neutronclient.common import exceptions
 from neutronclient.common import utils
-from neutronclient.i18n import _
 
 _logger = logging.getLogger(__name__)
 
@@ -40,19 +41,21 @@ else:
     _requests_log_level = logging.WARNING
 
 logging.getLogger("requests").setLevel(_requests_log_level)
+MAX_URI_LEN = 8192
+USER_AGENT = 'python-neutronclient'
 
 
 class HTTPClient(object):
     """Handles the REST calls and responses, include authn."""
 
-    USER_AGENT = 'python-neutronclient'
     CONTENT_TYPE = 'application/json'
 
-    # 8192 Is the default max URI len for eventlet.wsgi.server
-    MAX_URI_LEN = 8192
-
+    @debtcollector.renames.renamed_kwarg(
+        'tenant_id', 'project_id', replace=True)
+    @debtcollector.renames.renamed_kwarg(
+        'tenant_name', 'project_name', replace=True)
     def __init__(self, username=None, user_id=None,
-                 tenant_name=None, tenant_id=None,
+                 project_name=None, project_id=None,
                  password=None, auth_url=None,
                  token=None, region_name=None, timeout=None,
                  endpoint_url=None, insecure=False,
@@ -63,8 +66,8 @@ class HTTPClient(object):
 
         self.username = username
         self.user_id = user_id
-        self.tenant_name = tenant_name
-        self.tenant_id = tenant_id
+        self.project_name = project_name
+        self.project_id = project_id
         self.password = password
         self.auth_url = auth_url.rstrip('/') if auth_url else None
         self.service_type = service_type
@@ -85,7 +88,7 @@ class HTTPClient(object):
     def _cs_request(self, *args, **kwargs):
         kargs = {}
         kargs.setdefault('headers', kwargs.get('headers', {}))
-        kargs['headers']['User-Agent'] = self.USER_AGENT
+        kargs['headers']['User-Agent'] = USER_AGENT
 
         if 'body' in kwargs:
             kargs['body'] = kwargs['body']
@@ -136,7 +139,7 @@ class HTTPClient(object):
         if body:
             headers.setdefault('Content-Type', content_type)
 
-        headers['User-Agent'] = self.USER_AGENT
+        headers['User-Agent'] = USER_AGENT
 
         resp = requests.request(
             method,
@@ -151,9 +154,9 @@ class HTTPClient(object):
 
     def _check_uri_length(self, action):
         uri_len = len(self.endpoint_url) + len(action)
-        if uri_len > self.MAX_URI_LEN:
+        if uri_len > MAX_URI_LEN:
             raise exceptions.RequestURITooLong(
-                excess=uri_len - self.MAX_URI_LEN)
+                excess=uri_len - MAX_URI_LEN)
 
     def do_request(self, url, method, **kwargs):
         # Ensure client always has correct uri - do not guesstimate anything
@@ -181,7 +184,7 @@ class HTTPClient(object):
 
     def _extract_service_catalog(self, body):
         """Set the client's service catalog from the response data."""
-        self.auth_ref = access.AccessInfo.factory(body=body)
+        self.auth_ref = access.create(body=body)
         self.service_catalog = self.auth_ref.service_catalog
         self.auth_token = self.auth_ref.auth_token
         self.auth_tenant_id = self.auth_ref.tenant_id
@@ -189,9 +192,9 @@ class HTTPClient(object):
 
         if not self.endpoint_url:
             self.endpoint_url = self.service_catalog.url_for(
-                attr='region', filter_value=self.region_name,
+                region_name=self.region_name,
                 service_type=self.service_type,
-                endpoint_type=self.endpoint_type)
+                interface=self.endpoint_type)
 
     def _authenticate_keystone(self):
         if self.user_id:
@@ -201,12 +204,12 @@ class HTTPClient(object):
             creds = {'username': self.username,
                      'password': self.password}
 
-        if self.tenant_id:
+        if self.project_id:
             body = {'auth': {'passwordCredentials': creds,
-                             'tenantId': self.tenant_id, }, }
+                             'tenantId': self.project_id, }, }
         else:
             body = {'auth': {'passwordCredentials': creds,
-                             'tenantName': self.tenant_name, }, }
+                             'tenantName': self.project_name, }, }
 
         if self.auth_url is None:
             raise exceptions.NoAuthURLProvided()
@@ -273,6 +276,9 @@ class HTTPClient(object):
                 'auth_user_id': self.auth_user_id,
                 'endpoint_url': self.endpoint_url}
 
+    def get_auth_ref(self):
+        return getattr(self, 'auth_ref', None)
+
 
 class SessionClient(adapter.Adapter):
 
@@ -296,8 +302,15 @@ class SessionClient(adapter.Adapter):
         resp = super(SessionClient, self).request(*args, **kwargs)
         return resp, resp.text
 
+    def _check_uri_length(self, url):
+        uri_len = len(self.endpoint_url) + len(url)
+        if uri_len > MAX_URI_LEN:
+            raise exceptions.RequestURITooLong(
+                excess=uri_len - MAX_URI_LEN)
+
     def do_request(self, url, method, **kwargs):
         kwargs.setdefault('authenticated', True)
+        self._check_uri_length(url)
         return self.request(url, method, **kwargs)
 
     @property
@@ -336,13 +349,19 @@ class SessionClient(adapter.Adapter):
 
         return auth_info
 
+    def get_auth_ref(self):
+        return self.session.auth.get_auth_ref(self.session)
+
 
 # FIXME(bklei): Should refactor this to use kwargs and only
 # explicitly list arguments that are not None.
+@debtcollector.renames.renamed_kwarg('tenant_id', 'project_id', replace=True)
+@debtcollector.renames.renamed_kwarg(
+    'tenant_name', 'project_name', replace=True)
 def construct_http_client(username=None,
                           user_id=None,
-                          tenant_name=None,
-                          tenant_id=None,
+                          project_name=None,
+                          project_id=None,
                           password=None,
                           auth_url=None,
                           token=None,
@@ -350,7 +369,7 @@ def construct_http_client(username=None,
                           timeout=None,
                           endpoint_url=None,
                           insecure=False,
-                          endpoint_type='publicURL',
+                          endpoint_type='public',
                           log_credentials=None,
                           auth_strategy='keystone',
                           ca_cert=None,
@@ -359,7 +378,7 @@ def construct_http_client(username=None,
                           **kwargs):
 
     if session:
-        kwargs.setdefault('user_agent', 'python-neutronclient')
+        kwargs.setdefault('user_agent', USER_AGENT)
         kwargs.setdefault('interface', endpoint_type)
         return SessionClient(session=session,
                              service_type=service_type,
@@ -371,8 +390,8 @@ def construct_http_client(username=None,
         # refactor to use kwargs.
         return HTTPClient(username=username,
                           password=password,
-                          tenant_id=tenant_id,
-                          tenant_name=tenant_name,
+                          project_id=project_id,
+                          project_name=project_name,
                           user_id=user_id,
                           auth_url=auth_url,
                           token=token,
